Class: TelesignEnterprise::MessagingClient::OmniMessagingClient

Inherits:
Telesign::RestClient
  • Object
show all
Defined in:
lib/telesignenterprise/messaging.rb

Overview

Telesign Messaging allows you to easily send a message to the target recipient using any of Telesign's supported channels.

Instance Method Summary collapse

Constructor Details

#initialize(customer_id, api_key, rest_endpoint, timeout: nil) ⇒ OmniMessagingClient

Returns a new instance of OmniMessagingClient.



28
29
30
31
32
33
34
35
36
37
# File 'lib/telesignenterprise/messaging.rb', line 28

def initialize(customer_id,
  api_key,
  rest_endpoint,
  timeout: nil)

  super(customer_id,
  api_key,
  rest_endpoint: rest_endpoint,
  timeout: timeout)
end

Instance Method Details

#omni_message(**params) ⇒ Object



38
39
40
# File 'lib/telesignenterprise/messaging.rb', line 38

def omni_message(**params)
  self.post(OMNI_MESSAGING_RESOURCE, **params)
end